@@ -5,7 +5,7 @@ package App::Greple::md;
 use 5.024;
 use warnings;
 
-our $VERSION = "0.9902";
+our $VERSION = "0.9903";
 
 =encoding utf-8
 
@@ -25,6 +25,10 @@ App::Greple::md - Greple module for Markdown syntax highlighting
 
     greple -Mmd --no-table -- file.md
 
+    greple -Mmd --foldlist -- file.md
+
+    greple -Mmd -- --fold file.md
+
 =head1 DESCRIPTION
 
 B<App::Greple::md> is a L<greple|App::Greple> module for viewing
@@ -33,8 +37,9 @@ Markdown files in the terminal with syntax highlighting.
 It colorizes headings, bold, italic, strikethrough, inline code,
 fenced code blocks, HTML comments, blockquotes, horizontal rules,
 links, and images.  Tables are formatted with aligned columns and
-optional Unicode box-drawing borders.  Links become clickable via
-OSC 8 terminal hyperlinks in supported terminals.
+optional Unicode box-drawing borders.  Long lines in list items can
+be folded with proper indentation.  Links become clickable via OSC 8
+terminal hyperlinks in supported terminals.
 
 Nested elements are handled with cumulative coloring: for example,
 a link inside a heading retains both its link color and the heading
@@ -44,6 +49,27 @@ For a complete Markdown viewing experience with line folding,
 multi-column output, and themes, see L<App::mdee>, which uses this
 module as its highlighting engine.
 
+=head1 COMMAND OPTIONS
+
+The following options are defined as greple command options
+(specified after C<-->).
+
+=head2 B<--fold>
+
+Enable text folding for list items and definition lists.  Long lines
+are wrapped with proper indentation using L<ansifold(1)|App::ansifold>
+via L<Greple::tee>.  Code blocks, HTML comments, and tables are
+excluded from folding.  The fold width is controlled by the
+C<foldwidth> config parameter (default: 80).
+
+    greple -Mmd -- --fold file.md
+    greple -Mmd::config(foldwidth=60) -- --fold file.md
+
+Supported list markers: C<*>, C<->, C<1.>, C<1)>, C<#.>, C<#)>.
+
+The module option C<--foldlist> is a convenient alternative that
+enables folding via config.
+
 =head1 MODULE OPTIONS
 
 Module options are specified before C<--> to separate them from
@@ -65,6 +91,25 @@ L<Term::ANSIColor::Concise> color spec.
 
     greple -Mmd -B Crimson -- file.md
 
+=head2 B<--[no-]colorize>
+
+Enable or disable syntax highlighting.  Enabled by default.
+When disabled, no color is applied to Markdown elements.
+
+    greple -Mmd --no-colorize -- file.md
+
+=head2 B<--[no-]foldlist>
+
+Enable or disable text folding.  Disabled by default.  When
+enabled, long lines in list items and definition lists are wrapped
+with proper indentation.  The fold width is controlled by the
+C<foldwidth> config parameter (default: 80).
+
+    greple -Mmd --foldlist -- file.md
+    greple -Mmd::config(foldlist=1,foldwidth=60) file.md
+
+See also the C<--fold> command option.
+
 =head2 B<--[no-]table>
 
 Enable or disable table formatting.  When enabled (default),
@@ -146,6 +191,9 @@ Available parameters:
 
     mode            light or dark (default: light)
     base_color      base color override
+    colorize        syntax highlighting (default: 1)
+    foldlist        text folding (default: 0)
+    foldwidth       fold width in columns (default: 80)
     table           table formatting (default: 1)
     rule            box-drawing characters (default: 1)
     osc8            OSC 8 hyperlinks (default: 1)
@@ -175,8 +223,8 @@ Colors follow L<Term::ANSIColor::Concise> format.
     h2      L25D/${base}+y20;E       L00D/${base}-y15;E
     h3      L25DN/${base}+y30        L00DN/${base}-y25
     h4      ${base}UD                ${base}UD
-    h5      ${base}+y20;U            ${base}-y20;U
-    h6      ${base}+y20              ${base}-y20
+    h5      ${base}U                 ${base}U
+    h6      ${base}                  ${base}
 
 =head2 Inline Formatting
 
@@ -189,7 +237,8 @@ Colors follow L<Term::ANSIColor::Concise> format.
 
     LABEL        LIGHT              DARK
     code_mark    L20                L10
-    code_info    ${base_name}=y70   ${base_name}=y20
+    code_tick    L15/L23            L15/L05
+    code_info    ${base_name}=y70   L10
     code_block   /L23;E             /L05;E
     code_inline  L00/L23            L25/L05
 
@@ -229,6 +278,10 @@ Concise ANSI color specification format used for color labels.
 
 ANSI-aware column formatting used for table alignment.
 
+=item L<App::ansifold>
+
+ANSI-aware text folding used for line wrapping in list items.
+
 =back
 
 =head1 AUTHOR
@@ -252,6 +305,9 @@ my $config = Getopt::EX::Config->new(
     mode       => '',  # light / dark
     osc8       => 1,   # OSC 8 hyperlinks
     base_color => '',  # override base color
+    colorize   => 1,   # syntax highlighting
+    foldlist   => 0,   # text folding
+    foldwidth  => 80,  # fold width
     table      => 1,   # table formatting
     rule       => 1,   # box-drawing characters for tables
     heading_markup => 0,  # inline formatting in headings
@@ -269,6 +325,7 @@ my %base_color = (
 
 my %default_colors = (
     code_mark       => 'L20',
+    code_tick       => 'L15/L23',
     code_info       => '${base_name}=y70',
     code_block      => '/L23;E',
     code_inline     => 'L00/L23',
@@ -280,8 +337,8 @@ my %default_colors = (
     h2              => 'L25D/${base}+y20;E',
     h3              => 'L25DN/${base}+y30',
     h4              => '${base}UD',
-    h5              => '${base}+y20;U',
-    h6              => '${base}+y20',
+    h5              => '${base}U',
+    h6              => '${base}',
     bold            => 'D',
     italic          => 'I',
     strike          => 'X',
@@ -291,15 +348,16 @@ my %default_colors = (
 
 my %dark_overrides = (
     code_mark       => 'L10',
-    code_info       => '${base_name}=y20',
+    code_tick       => 'L15/L05',
+    code_info       => 'L10',
     code_block      => '/L05;E',
     code_inline     => 'L25/L05',
     h1              => 'L00D/${base};E',
     h2              => 'L00D/${base}-y15;E',
     h3              => 'L00DN/${base}-y25',
     h4              => '${base}UD',
-    h5              => '${base}-y20;U',
-    h6              => '${base}-y20',
+    h5              => '${base}U',
+    h6              => '${base}',
 );
 
 sub default_theme {
@@ -327,7 +385,8 @@ my %show;
 sub finalize {
     my($mod, $argv) = @_;
     $config->deal_with($argv,
-                       "mode|m=s", "base_color|B=s", "table!", "rule!",
+                       "mode|m=s", "base_color|B=s",
+                       "colorize!", "foldlist!", "foldwidth=i", "table!", "rule!",
                        "heading_markup|hm:s",
                        "hashed=s%",
                        "colormap|cm=s" => \@opt_cm,
@@ -337,6 +396,13 @@ sub finalize {
     if (defined $hm && $hm eq '') {
         $config->{heading_markup} = 'all';
     }
+    if (my $w = $config->{foldwidth}) {
+        $mod->setopt('--fold', "--fold-by $w");
+        if ($config->{foldlist}) {
+            my @default = $mod->default;
+            $mod->setopt('default', @default, "--fold-by $w");
+        }
+    }
 }
 
 sub setup_colors {
@@ -489,7 +555,7 @@ my %colorize = (
     },
     inline_code => sub {
         s/(?<bt>`++)(((?!\g{bt}).)+)(\g{bt})/
-            protect(md_color('code_mark', $+{bt}) . md_color('code_inline', $2) . md_color('code_mark', $4))
+            protect(md_color('code_tick', $+{bt}) . md_color('code_inline', $2) . md_color('code_tick', $4))
         /ge;
     },
     headings => sub {
@@ -590,12 +656,11 @@ sub colorize {
 #
 
 sub begin {
-    colorize();
-    format_table();
+    colorize()    if $config->{colorize};
+    format_table() if $config->{table};
 }
 
 sub format_table {
-    return unless $config->{table};
     my $sep = $config->{rule} ? "\x{2502}" : '|';  # │ or |
 
     s{(^ {0,3}\|.+\|\n){3,}}{
@@ -635,3 +700,22 @@ __DATA__
 option default \
     -G --filter --filestyle=once --color=always \
     --begin &__PACKAGE__::begin
+
+define {CODE_BLOCK}  ^ {0,3}(?<bt>`{3,}+|~{3,}+)(.*)\n((?s:.*?))^ {0,3}(\g{bt})
+define {COMMENT}     ^<!--(?![->])(?s:.+?)-->
+define {TABLE}       ^ {0,3}([│|├].+[│|┤]\n){3,}
+define {LIST_ITEM}   ^\h*(?:[*-]|(?:\d+|#)[.)])\h+.*\n
+define {DEFINITION}  (?:\A|\G\n|\n\n).+\n\n?(:\h+.*\n)
+
+option --fold-by \
+    -Mtee "&ansifold" --crmode \
+        --autoindent='^\h*(?:[*-]|(?:\d+|#)[.)]|:)\h+|^\h+' \
+        --smart --width=$<shift> \
+    -- \
+    --exclude {CODE_BLOCK} \
+    --exclude {COMMENT} \
+    --exclude {TABLE} \
+    --cm N -E {LIST_ITEM} \
+    --cm N -E {DEFINITION} \
+    --crmode
+
